---
layout: assignment
published: true

title: AT Around Us
code: hw3

assigned: Jan 24, 2023
due: 
   - Jan 31, 2023, 5pm (no grace period this week because you present in class)
 
revised: Jan 3, 2023

---

<!-- make due at least 24 hours ahead of presentation as a best practice in accessible presenting -->
 
* TOC
{:toc}


# Learning Goals

This assignment will expose the class to a range of in-use accessibility technologies, and give you experience with seeking out first-person accounts of disability experiences with technology. It will also give you experience with presenting accessibly.

## 0. Learn about how to present accessibly

Watch [a video about presenting
accessible](https://www.youtube.com/watch?v=L9TxhGv91kc) by Kyle
Rector. Review information about [describing images](https://webaim.org/techniques/alttext/) and [describing people](https://www.youtube.com/watch?v=By6nzFefcxs) in images verbally (during a presentation) or in text. Finally, make sure you don't use [abelist language](https://www.popsugar.com/fitness/common-phrases-that-are-ableist-48080654). 

Optional reading [Its complicated: Negotiating Accessibility and
(Mis)Representation in Image Descriptions of Race, Gender and
Disability](https://guoanhong.com/papers/CHI21-ImageDescriptions.pdf)


## 1. Select two examples of an accessibility technology or disability hack

Select two examples of accessibility technology, or disability hack, that you will be presenting about. Roughly speaking, one technology should improve computer access  and one should improve access to "the world" at large; and at least one should involve computers in some way. Try not to pick the same thing as someone else in the class. Also do not choose really really common things (like elevators and glasses).  

An accessibility technology is something that is used by a person with a disability to increase accessibility. It can be something that is included in the infrastructure (such as a [curb cut](https://en.wikipedia.org/wiki/Curb_cut)) or something that is used by an individual (such as [Proloque2Go](https://www.talktometechnologies.com/pages/proloquo2go), a symbol-based communication system), or something that was not designed for accessibility bit is useful (such as these [5 disability life hacks](https://www.spinalcord.com/blog/5-inexpensive-disability-life-wheelchair-hacks))

In addition, you should pick something that *expands your knowledge of accessibility technology.* You should include two different technologies that 
- You are not already familiar with
- Between them address diverse needs. For example, one of your two technologies might improve access to the world (such as Microsoft's [Seeing AI](https://www.microsoft.com/en-us/ai/seeing-ai)); the other could improve access to the computer (such as [sticky keys](https://en.wikipedia.org/wiki/Sticky_keys)) or a screen reader. Or one of your two technologies should improve access using an infrastructure approach; the other can use an individual approach. 
- Are designed specifically for the disability community, or are mainstream technologies being used in to address access specific needs. Especially if they are mainstream technologies, you should explain what range of disabilities they support (for example, audio books help people who are blind or low vision, as well as people who are dyslexic, or cannot look at a screen without experiencing chronic illness symptoms). 

## 2. Find and Generate First Person Experiences

Find first person accounts *by a person with a disability* that is *not an advertisement* describing each technology and how they use it. A first person account is written or presented by someone who
- Uses this technology themselves on a regular basis
- has a disability

A first person account that meets the requirements of this assignment is not
- a teaching video/presentation
- an advertisement.
- based on your personal experience 

For example, here is a [personal perspective on audio crosswalks](https://www.youtube.com/watch?v=xPlsYhU1HBU) and here is an interview with two black AAC users about their experiences using AAC technology (start at 00:16:00)

<iframe width="560" height="315" src="https://www.youtube.com/embed/iTSAK4yRf5A" title="YouTube video player" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share" allowfullscreen></iframe>

Alternatively, you should find a blog or review written by a personal with a disability who would benefit from the AT that you are trying to learn about. This may influence your choice of technologies, it is OK to iterate. 

In addition, *try it yourself*. While some technologies may be expensive or hard to get, many accessibility technologies are easily available and some are even re-purposed everyday items. To meet the requirements for this assignment, you'll also need to make sure that at least one of your chosen technologies is something you can try yourself

## 3. Reflect on What you Learned

Take some time to reflect on these questions, which will help you to preare for your presentation

What is the AT?
- What is the technology?
- What does the AT do?
- What is the access gap that the AT is attempting to address?
- Why was it developed?

How well does it suit users? 
- What is its audience? Think outside the box (e.g. did you know that screen readers are used by BLV people, people with dyslexia, and people with other reading disabilities?)
- What are its strengths and/or weaknesses?
- What are the benefits that were not encompassed by the original intent?
- Do the intended users like it?
- What do the intended users find frustrating about using it?
<!-- If you were to work on a project to address a user-faced frustration or limitation of this AT: -->
<!-- - How would you improve this AT? -->
<!-- - How can you say that the improvement you make can address the user-level frustration or deficiency of this AT? -->
- If you have a chance to interview users of this technology, what would be one question you would ask, that was not answered in your search for information?

# Turnin

1. You will create one accessible slides (per AT) in a shared slide deck posted in the [Class Discussion]({{site.piazza}}) and on [Canvas]({{site.canvas}}). Your slide should include 
- A summary of the AT you researched 
- Information about its audience 
- A picture of it
- A link to the first person account you found
- Something you learned from the video and/or by trying it about its strengths and weaknesse

2. You will present at least one of those slides in class. You should be prepared to 
- Stay on time (3-4 minutes + 1-2 minutes of questions). This will require you to pick and choose what to focus on when you design your slide, and to practice ahead of class.
- Be accessible (you may want to revisit  [presenting accessible](https://www.youtube.com/watch?v=L9TxhGv91kc) by Kyle Rector)

# Competencies
This homework will contribute to your competency grade on 
- Image description
- Accessible presentation creation 
- Presenting accessibly to an audience with mixed disabilities
- Finding first person accounts by and for people with disabilities
- Familiarity with a range of accessibility technologies (requires being present and engaged with student presentations) 
- Your participation grade, as a percentage of completeness (are all the required parts present)
