---
layout: assignment
published: true

title: Technology Review
code: hw4

assigned: Jan 31, 2023
due: 
   - Feb 7, 2023, 5pm Pacific
   - Two day grace period, Feb 9, 2023
  
revised: Feb 5, 2023

---

* TOC
{:toc}

# Learning Goals

This assignment will expose the class to a range of in-use accessibility technologies, and give you experience with seeking out first-person accounts of disability experiences with technology. It will also give you experience with presenting accessibly.

## 1. Select one example of second wave technology and read about it/try it

Select an example of a so-called <q>second wave</q> technology, that you will *write* or *make a video* about. Your goal is to  (1) summarize some accessibility research with that technology for a general audience and then (2) give a survey of some common accessible solutions available today for people with disabilities who want to try the technology (here you can do more of a survey, links to actual available stuff is ideal)

We have a couple of requests from community partners, and you can also select something based on interest. Once you select that technology, you should pick one paper to read deeply, and also try out some of accessible examples of the technology that are available now (you may need to search around to find these). The details of what you read, and try out, may vary with the topic you pick ad you can check with the instructors if you are unsure. 

{% details Possible technologies %}
Those marked with CA are *CREATE ASK* topics, i.e. topics that CREATE partners have asked us to provide them with content about. Those with MA are *Maybe Ask* topics, i.e. relevant to a community partner but not a direct ask. Essays on those topics may be shared more broadly in CREATE or partner publications.

- CA: Educational Games for young children ([PAVE](https://wapave.org/)). Articles: [A preliminary analysis of Android educational game accessibility](https://dl.acm.org/doi/abs/10.1145/3441852.3476532) ; [Web-based serious games and accessibility: A systematic literature review](https://www.mdpi.com/2076-3417/10/21/7859); [Video games and disability: Looking back at a challenging decade](https://www.polygon.com/2020/1/8/21056713/disabilities-video-game-characters-inclusion-accessibility-decade-in-review). Available now: [games that are accessible](https://www.pbs.org/parents/thrive/supporting-your-child-with-disabilities-with-digital-learning-games#:~:text=Four%20games%20from%20the%20long,can%20receive%20similar%20learning%20benefits.) (you may need to try these to confirm); [Celeste](https://store.steampowered.com/app/504230/Celeste/)
- CA: Online spaces for kids with disabilities (any age) ([PAVE](https://wapave.org/)). Articles: [Would you be mine: Appropriating Minecraft as an assistive technology for youth with autism](https://dl.acm.org/doi/abs/10.1145/2982142.2982172); [You're my best friend: Finding community online in BTS's Fandom, ARMY](https://dl.acm.org/doi/pdf/10.1145/3495266); [My voice is definitely strongest in online communities: Students using social media for queer and disability identity making](https://muse.jhu.edu/pub/1/article/663305). Available now: [first-person account of what that means](https://www.forbes.com/sites/andrewpulrang/2021/05/31/how-to-find-your-disability-community/?sh=3388225010fe)
- CA: Tools for learning programming ([PAVE](https://wapave.org/)); possible Hope Vision). Articles: [Blocks4All: Overcoming accessibility barriers to blocks programming for children with visual impairments](https://dl.acm.org/doi/abs/10.1145/3173574.3173643); [Physical programming for blind and low vision children at scale](https://www.tandfonline.com/doi/full/10.1080/07370024.2019.1621175?casa_token=6bNihQzh67EAAAAA%3AxPJWDluwJ7Q6xhted7fT9UW9Y7v-HMSMRIS1Rj1rLd0AaExkr-5IWkMM408DoNn9QOe1xFn9UKvm). Available now: [Blocks4all](https://milnel2.github.io/blocks4alliOS/); [Quorum](https://quorumlanguage.com/); [Microcode](https://learn.adafruit.com/microcode-for-microbit) 
- MA: Sports & eSports (e.g. [Seattle Adaptive Sports](http://www.seattleadaptivesports.org/)). Articles: [Design and real world evaluation of Eyes-Free Yoga: An Exergame for  blind & low vision exercise](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC5667683/); [Design in the public square: supporting assistive technology design through public mixed-ability cooperation](https://dl.acm.org/doi/pdf/10.1145/3359257); [Accessibility in gaming](https://www.scope.org.uk/campaigns/research-policy/accessibility-in-gaming/#Interests-and-behaviours-among-disabled-gamers) (UK report). Available now: [Xbox adaptive controller](https://www.xbox.com/en-US/accessories/controllers/xbox-adaptive-controller); [Dr. Gearbox](https://store.steampowered.com/app/1218220/The_Mechanical_World_of_Dr_Gearbox/) with ["playable characters show people living with different conditions and disabilities"](https://altagram.com/people-with-disabilities-changing-esports/); [Ablegamers.org](https://ablegamers.org/impact/); numerous first person accounts by disabled gamers. 
- MA: Visualization. Articles: [Communicating Visualizations without Visuals: Investigating Visualization Alternative Text for People with Visual Impairments](https://ieeexplore.ieee.org/document/9552938); [Infosonics: Accessible Infographics for people who are blind using sonification and voice](https://dl.acm.org/doi/10.1145/3491102.3517465); [How accessible is my visualization? Evaluating visualization accessibility with Chartability](https://onlinelibrary.wiley.com/doi/full/10.1111/cgf.14522?casa_token=6uJ3npedmwsAAAAA%3ABeZrqQUFLWkVzgZHtxa29Oqh199mf4_A_eSPsdzpREK0Wm-n5uRCPymODes0W2MDSlUr1yBXX6f-MVY). Available now: The best tools available now still require a *programmer* to use them [HighCharts](https://www.highcharts.com/docs/accessibility/accessibility-module); [Voxlens](https://github.com/athersharif/voxlens). A "live" list that has the latest on what's available [DataViz A11y](https://github.com/dataviza11y/resources)
- Fabrication & Physical Computing. Articles: [Sharing is caring: Assistive technology designs on thingiverse](https://dl.acm.org/doi/10.1145/2702123.2702525); [Making "making" accessible](https://dl.acm.org/doi/10.1145/2485760.2485883); [Putting tools in hands: Designing curriculum for a nonvisual soldering workshop](https://doi.org/10.1145/3373625.3418011); [Designing educational materials for a blind arduino workshop](https://doi.org/10.1145/3334480.3383055). Available now: [Blind Arduino Blog](http://blarbl.blogspot.com/); (much older) [Smith Ketterwell Technical File](https://www.ski.org/smith-kettlewell-technical-file); [Nonvisual soldering](https://laurenrace.com/teaching/nonvisual-curriculum-design/); [Nonvisual arduino](https://laurenrace.com/teaching/nonvisual-arduino-workshop/)
- Security/Privacy. Articles: [AccessiLeaks: Investigating privacy leaks exposed by the Android accessibility service](https://hal.inria.fr/hal-01929049/file/naseri-popets19.pdf); [A survey of privacy concerns of smart-home services provided to individuals with disabilities](https://www.ncbi.nlm.nih.gov/pmc/articles/PMC7070117/); [I'm literally just hoping this will work: Obstacles blocking the online security and privacy of users with disabilities](https://www.usenix.org/system/files/soups2021-napoli.pdf). Available now: I'm not sure what to put here (feel free to try to find something). Aside from audio-enabled captchas, the other issues raised here are not something that an existing online app can necessarily address. 
- MA VR/AR (e.g. [Northwest School for the Deaf and Hard of Hearing](https://www.northwestschool.com/)). Articles:  [A systematic literature review of handheld augmented reality solutions for people with disabilities](https://www.mdpi.com/1424-8220/22/20/7719); [AR4VI: AR as an accessibility tool for people with visual impairments](https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=8088507&casa_token=T2X3w3jTOugAAAAA:Mlnt-Wqk7Y4W-bJndK5Hgc8wbnL2QDVT-JSUZNaxheR2p5h5NPgSsn94TbYTiScUwwJvJBQcySY4); [SeeingVR: A set of tools to make virtual reality more accessible to people with low vision](https://www.classes.cs.uchicago.edu/archive/2020/winter/20370-1/readings/SeeingVR.pdf). Available now: [OverTHERE](https://apps.apple.com/us/app/overthere/id1126056833); [Honor Everywhere](https://www.oculus.com/experiences/go/1634724596608007/); [Accessibility, Disabilities, and Virtual Reality Solutions](https://educatorsinvr.com/2019/05/31/accessibility-disabilities-and-virtual-reality-solutions/)
- Other: You are welcome to tackle other areas covered in class including [AI/ML](https://arxiv.org/abs/2208.04712); [Intelligent Agents](http://acm.mementodepot.org/pubs/proceedings/acmconferences_3173574/3173574/3173574.3174033/3173574.3174033.pdf); you will need to work with the instructors to identify a set of reading papers and technololgies that are available now. 
{% enddetails %}

## 2. Write/Talk about the technology  

You should write or talk about the technology. Your writeup should 

1. Describe the topic 
   a. Introduce the technology you focused on (1 paragraph)
   b. Summarize what might be important to know about the technology from a disability perspective (1-2 paragraphs), including things that can impact its accessibility
   
2. Summarize what you learned about the topic from the research article. It is ok to mention more than one article, and we selected articles that complement each other. However, you are only *required* to summarize a single article. (4-5 paragraphs)
3. Describe solutions and/or options *available now* to people with disabilities. For each one, Describe it briefly; Provide a link
4. Conclude by summarizing the key take aways
    

Please make sure that the document
and/or video you produce is accessible. In the case of the document,
you should use a single column format; label headers properly (in
word, pdf, or html); and include alt text for images (again in any
format). In the case of a video, you should present accessibly; and
include captions and verbally describing important visual elements.

# Turnin

You will turn this assignment in on canvas.

- Upload your document or link to your video
- Upload a document containing the ALT text for each figure and/or the caption file for your video

# Competencies
This homework may contribute to your competency grade on 
- Image description
- Accessible presentation 
- Accessible video creation 
- Accessible document creation
- Your participation grade, as a percentage of completeness (are all the required parts present)
